PhotoViewWidget constructor
images are the images will be shown
index is the position of the initial image to show firstly
Implementation
const PhotoViewWidget({
required this.images,
required this.index,
required this.showControls,
});
images are the images will be shown
index is the position of the initial image to show firstly
const PhotoViewWidget({
required this.images,
required this.index,
required this.showControls,
});